@@ -24,6 +24,7 @@ from syntribos.clients.http.client import SynHTTPClient
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
+LOG.addHandler(logging.StreamHandler())
 temp_dirs = []
 remote_dirs = []
 
@@ -62,7 +63,8 @@ def download(uri, cache_dir=None):
         temp_dirs.append(cache_dir)
     remote_dirs.append(cache_dir)
     LOG.debug("Remote file location: %s", remote_dirs)
-    resp, _ = SynHTTPClient().request("GET", uri)
+    _kwargs = {'allow_redirects': True}
+    resp, _ = SynHTTPClient().request("GET", uri, requestslib_kwargs=_kwargs)
     os.chdir(cache_dir)
     saved_umask = os.umask(0o77)
     fname = uri.split("/")[-1]
@@ -87,7 +89,7 @@ def extract_tar(abs_path):
     try:
         os.mkdir("remote")
     except OSError:
-        LOG.error("path exists already, not creating remote directory.")
+        LOG.error("Path exists already, not creating remote directory.")
     remote_path = os.path.abspath("remote")
 
     def safe_paths(tar_meta):
